% Example of fitting scattered data of 3 independent variables

load MgSO4Data

% Saved in this file are 
%     "P" "T" "m" "v" "dv"  vectors of scattered data including the Vance and Brown measurements 
%      and other literature reported  values including IAPWS for pure water below 400 MPa.
%      where pressure is in MPa, T in K, m in mol/kg, and v and dv in km/s

% set up the fit parameters of damping, regularization, spline
% order,derivative to minimize, and control points
lam=2*[1 1 1];
RegFac=[1  1 1];
Ordr=[4 4 4];
mdrv=[2 2 2];
% control points in P T and molality
Tc=240:10:380;
Pc=0:10:800;
mc=[0:.2:3];

% do the fit (note independent variables input as a matrix that is 3 wide
sp_ptm=spdft([P(:) T(:) m(:)],v(:),dv(:),{Pc,Tc,mc},lam,RegFac,Ordr,mdrv,[]);

% calculate deviations of the surface from the the Vance and Brown data
devs=[];
Pdevs=[];
ncount=0;
%
% evaluate fit and deviations at data points
vc=fnval(sp_ptm,[P(:) T(:) m(:)]');
devs=100*(v-vc)./v;

% plotting grid:
mplt=[0 .08 .51 .997 1.51 2.02];
Pplt=0:50:800;
Tplt=240:10:380;
nP=length(Pplt);
nT=length(Tplt);
% calculate the sound speed surface on the plotting grid
vplt=fnval(sp_ptm,{Pplt,Tplt,mplt});
%%
%make plots
scrsz=get(0,'ScreenSize');
figsz=[1 .9*scrsz(4) 3*scrsz(3)/4 .9*scrsz(4)];
h=figure('Name','Three Independent Variables','Position',figsz);
colormap gray

subplot(221)
for i=1:6
surf(Pplt,Tplt,squeeze(vplt(:,:,i))') 
hold on
end

plot3(P,T,v,'ko','MarkerFaceColor','k')
hold off
xlabel('Pressure (MPa)')
ylabel('Temperature (K)')
zlabel('Sound Speed km/s)')
title('Data Plus Selected Compositional Surfaces')


subplot(222)
nt=length(Tplt);
for i=1:3:nt
surf(Pplt,mplt,squeeze(vplt(:,i,:))')
hold on
end
hold off
xlabel('Pressure (MPa)')
ylabel('Molality (mole/Kg)')
zlabel('Sound Speed km/s)')
title('Selected Temperature Surfaces')

subplot(223)
np=length(Pplt);
for i=1:3:np
surf(Tplt,mplt,squeeze(vplt(i,:,:))')
hold on
end
hold off
xlabel('Temperatures (K)')
ylabel('Molality (mole/Kg)')
zlabel('Sound Speed km/s)')
title('Selected Pressure Surfaces')

subplot(224)
plot(P,devs,'ko','MarkerFaceColor','k')
xlabel('Pressure (MPa)')
ylabel('Deviations (%)')
title('Data Deviations from Surface')

